========
Geospots
========



.. image:: https://img.shields.io/pypi/v/geospots.svg
        :target: https://pypi.python.org/pypi/geospots

.. image:: https://img.shields.io/travis/pedroportelas/geospots.svg
        :target: https://travis-ci.com/pedroportelas/geospots

.. image:: https://readthedocs.org/projects/geospots/badge/?version=latest
        :target: https://geospots.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Geospots contains functions for working with spatial data. Developed for SpotsApp support and standalone usage.


* Documentation: https://geospots.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
